from django.db import models
from articles.models import Article
from django.core.validators import MinValueValidator
from decimal import Decimal
from infosachats.models import InfoAchat
from infosventes.models import InfoVente
from fournisseurs.models import Fournisseur
# Create your models here.
class Lot(models.Model):
	article = models.ForeignKey(Article, on_delete=models.CASCADE, null=True, blank=True)
	date_arrivage =  models.DateField(null=True, blank=True)
	quantitee_ouverture = models.DecimalField(decimal_places=0, max_digits=19, blank=True, default=0, validators=[MinValueValidator(Decimal('0.00'))])
	quantitee = models.DecimalField(decimal_places=0, max_digits=19, blank=True, default=0, validators=[MinValueValidator(Decimal('0.00'))])
	numero_lot = models.CharField(max_length=32, null=True, blank=True, unique = True)
	infosachat = models.ForeignKey(InfoAchat, on_delete=models.CASCADE, null=True, blank=True)
	infosvente = models.ForeignKey(InfoVente, on_delete=models.CASCADE, null=True, blank=True)
	fournisseur = models.ForeignKey(Fournisseur, on_delete=models.SET_NULL, null=True, blank=True)
	upc = models.CharField(max_length=32, null=True, blank=True)
	revenu = models.DecimalField(decimal_places=2, max_digits=19, blank=True, default=0, validators=[MinValueValidator(Decimal('0.00'))])
	created_at = models.DateTimeField(auto_now_add=True)
	updated_at = models.DateTimeField(auto_now=True)